@@ -37,7 +37,6 @@
 #include "gtr-file-dialogs.h"
 #include "gtr-notebook.h"
 #include "gtr-po.h"
-#include "gtr-statusbar.h"
 #include "gtr-tab.h"
 #include "gtr-utils.h"
 #include "gtr-window.h"
@@ -96,15 +95,6 @@ gtr_open (GFile * location, GtrWindow * window, GError ** error)
   active_view = gtr_tab_get_active_view (tab);
   gtk_widget_grab_focus (GTK_WIDGET (active_view));
 
-  gtr_statusbar_update_progress_bar (GTR_STATUSBAR
-                                     (gtr_window_get_statusbar
-                                      (window)),
-                                     (gdouble)
-                                     gtr_po_get_translated_count
-                                     (po),
-                                     (gdouble)
-                                     gtr_po_get_messages_count (po));
-
   gtr_window_show_poeditor (window);
 
   return TRUE;
@@ -161,26 +151,60 @@ gtr_file_chooser_analyse (gpointer dialog,
 {
   gint reply;
 
-  reply = gtk_dialog_run (GTK_DIALOG (dialog));
-  switch (reply)
-    {
-    case GTK_RESPONSE_ACCEPT:
-      if (mode == FILESEL_OPEN)
-        {
-          gtr_po_parse_files_from_dialog (GTK_WIDGET (dialog), window);
-        }
-      break;
-    case GTK_RESPONSE_CANCEL:
-      gtk_widget_hide (GTK_WIDGET (dialog));
-      break;
-    case GTK_RESPONSE_DELETE_EVENT:
-      gtk_widget_hide (GTK_WIDGET (dialog));
-      break;
-    default:
-      break;
-    }
+  reply = gtk_native_dialog_run (GTK_NATIVE_DIALOG (dialog));
+  if (reply == GTK_RESPONSE_ACCEPT && mode == FILESEL_OPEN)
+    gtr_po_parse_files_from_dialog (GTK_WIDGET (dialog), window);
+
+  g_object_unref (dialog);
 }
 
+gboolean
+gtr_want_to_save_current_dialog (GtrWindow * window)
+{
+  gint res = 0;
+  GtrTab *tab;
+  GtrPo *po;
+
+  g_autoptr (GtkWidget) dialog = NULL;
+  g_autoptr (GFile) location = NULL;
+  g_autofree gchar *filename = NULL;
+  g_autofree gchar *markup = NULL;
+
+  tab = gtr_window_get_active_tab (window);
+  po = gtr_tab_get_po (tab);
+  location = gtr_po_get_location (po);
+  filename = g_file_get_path (location);
+
+  dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+                                   GTK_MESSAGE_WARNING,
+                                   GTK_BUTTONS_NONE, NULL);
+
+  markup = g_strdup_printf (
+    _("Do you want to save changes to this file: "
+      "<span weight=\"bold\" size=\"large\">%s</span>?"),
+    filename);
+
+  gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), markup);
+  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+    _("If you don't save, all your unsaved changes will be permanently lost."));
+
+  gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+                          _("Save and open"), GTK_RESPONSE_YES,
+                          _("Cancel"), GTK_RESPONSE_CANCEL,
+                          _("Continue without saving"), GTK_RESPONSE_NO,
+                          NULL);
+
+  res = gtk_dialog_run (GTK_DIALOG (dialog));
+
+  if (res == GTK_RESPONSE_CANCEL)
+    return FALSE;
+
+  if (res == GTK_RESPONSE_YES)
+    gtr_save_current_file_dialog (NULL, window);
+
+  return TRUE;
+}
 
 /*
  * The "Open file" dialog.
@@ -189,48 +213,20 @@ void
 gtr_open_file_dialog (GtkAction * action, GtrWindow * window)
 {
   GtkWidget *dialog = NULL;
-  GList *list;
+  g_autoptr (GList) list = NULL;
 
   list = get_modified_documents (window);
   if (list != NULL)
     {
-      GtkWidget *dialog;
-      gint res;
-
-      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-            GTK_DIALOG_DESTROY_WITH_PARENT,
-            GTK_MESSAGE_QUESTION,
-            GTK_BUTTONS_YES_NO,
-            _("Do you want to save the changes?"));
-      gtk_window_set_title (GTK_WINDOW (dialog), _("Warning"));
-      g_list_free (list);
-      res = gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
-
-      if (res == GTK_RESPONSE_YES)
-      {
-	gtr_save_current_file_dialog (NULL, window);
-      }
+      if (!gtr_want_to_save_current_dialog (window))
+        return;
     }
 
-  if (dialog != NULL)
-    {
-      gtk_window_present (GTK_WINDOW (dialog));
-      return;
-    }
   dialog = gtr_file_chooser_new (GTK_WINDOW (window),
                                  FILESEL_OPEN,
                                  _("Open file for translation"),
                                  _gtr_application_get_last_dir (GTR_APP));
 
-  /*
-   * With the gettext parser/writer API, we can't currently read/write
-   * to remote files with gnome-vfs. Eventually, we should intercept
-   * remote requests and use gnome-vfs to retrieve a temporary file to 
-   * work on, and transmit it back when saved.
-   */
-  //gtk_file_chooser_set_local_only(GTK_FILE_CHOOSER(dialog), TRUE);
-
   gtr_file_chooser_analyse ((gpointer) dialog, FILESEL_OPEN, window);
 }
 
@@ -243,7 +239,6 @@ save_dialog_response_cb (GtkDialog * dialog,
   GtrTab *tab;
   gchar *filename;
   GFile *location;
-  GtrStatusbar *status;
 
   tab = GTR_TAB (g_object_get_data (G_OBJECT (dialog), GTR_TAB_SAVE_AS));
 
@@ -253,7 +248,7 @@ save_dialog_response_cb (GtkDialog * dialog,
 
   if (response_id != GTK_RESPONSE_ACCEPT)
     {
-      gtk_widget_destroy (GTK_WIDGET (dialog));
+      g_object_unref (dialog);
       return;
     }
 
@@ -263,7 +258,7 @@ save_dialog_response_cb (GtkDialog * dialog,
   location = g_file_new_for_path (filename);
   g_free (filename);
 
-  gtk_widget_destroy (GTK_WIDGET (dialog));
+  g_object_unref (dialog);
 
   if (po != NULL)
     {
@@ -289,10 +284,6 @@ save_dialog_response_cb (GtkDialog * dialog,
 
       /* We have to change the state of the tab */
       gtr_po_set_state (po, GTR_PO_STATE_SAVED);
-
-      /* Flash a message */
-      status = GTR_STATUSBAR (gtr_window_get_statusbar (window));
-      gtr_statusbar_flash_message (status, 0, _("File saved."));
     }
   g_object_unref (location);
 }
@@ -325,9 +316,7 @@ gtr_save_file_as_dialog (GtkAction * action, GtrWindow * window)
 {
   GtkWidget *dialog = NULL;
   GtrTab *current_page;
-  GtrPo *po;
-  GFile *location;
-  gchar *uri = NULL;
+  gint reply = 0;
 
   if (dialog != NULL)
     {
@@ -336,12 +325,10 @@ gtr_save_file_as_dialog (GtkAction * action, GtrWindow * window)
     }
 
   current_page = gtr_window_get_active_tab (window);
-  po = gtr_tab_get_po (current_page);
-
   dialog = gtr_file_chooser_new (GTK_WINDOW (window),
                                  FILESEL_SAVE,
                                  _("Save file as…"),
-                                 _gtr_application_get_last_dir (GTR_APP));
+                                 g_get_home_dir ());
 
   gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog),
                                                   TRUE);
@@ -350,29 +337,10 @@ gtr_save_file_as_dialog (GtkAction * action, GtrWindow * window)
                     G_CALLBACK (confirm_overwrite_callback), NULL);
 
   gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-
-  /*Set the suggested file */
-  location = gtr_po_get_location (po);
-
-  uri = g_file_get_uri (location);
-
-  g_object_unref (location);
-
-  if (uri)
-    gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (dialog), uri);
-
-  g_free (uri);
-
-  /*
-   * FIXME: If we can't set the uri we should add a default path and name
-   */
-
   g_object_set_data (G_OBJECT (dialog), GTR_TAB_SAVE_AS, current_page);
 
-  g_signal_connect (dialog,
-                    "response", G_CALLBACK (save_dialog_response_cb), window);
-
-  gtk_widget_show (GTK_WIDGET (dialog));
+  reply = gtk_native_dialog_run (GTK_NATIVE_DIALOG (dialog));
+  save_dialog_response_cb (GTK_DIALOG (dialog), reply, window);
 }
 
 /*
@@ -384,7 +352,6 @@ gtr_save_current_file_dialog (GtkWidget * widget, GtrWindow * window)
   GError *error = NULL;
   GtrTab *current;
   GtrPo *po;
-  GtrStatusbar *status;
 
   current = gtr_window_get_active_tab (window);
   po = gtr_tab_get_po (current);
@@ -406,10 +373,6 @@ gtr_save_current_file_dialog (GtkWidget * widget, GtrWindow * window)
 
   /* We have to change the state of the tab */
   gtr_po_set_state (po, GTR_PO_STATE_SAVED);
-
-  /* Flash a message */
-  status = GTR_STATUSBAR (gtr_window_get_statusbar (window));
-  gtr_statusbar_flash_message (status, 0, _("File saved."));
 }
 
 static gboolean
@@ -776,7 +739,6 @@ _gtr_actions_file_save_all (GtkAction * action, GtrWindow * window)
   for (l = list; l != NULL; l = g_list_next (l))
     {
       GError *error = NULL;
-      GtrStatusbar *status;
 
       gtr_po_save_file (GTR_PO (l->data), &error);
 
@@ -798,12 +760,7 @@ _gtr_actions_file_save_all (GtkAction * action, GtrWindow * window)
 
       /* We have to change the state of the tab */
       gtr_po_set_state (GTR_PO (l->data), GTR_PO_STATE_SAVED);
-
-      /* Flash a message */
-      status = GTR_STATUSBAR (gtr_window_get_statusbar (window));
-      gtr_statusbar_flash_message (status, 0, _("Files saved."));
     }
 
   g_list_free (list);
 }
-
