@@ -34,7 +34,6 @@
 
 #include "gtr-actions.h"
 #include "gtr-msg.h"
-#include "gtr-statusbar.h"
 #include "gtr-utils.h"
 #include "gtr-view.h"
 #include "gtr-window.h"
@@ -307,6 +306,8 @@ do_find (GtrSearchBar * dialog, GtrWindow * window, gboolean search_backwards)
 
   if (!found && current_msg)
     gtr_tab_message_go_to (tab, current_msg->data, FALSE, GTR_TAB_MOVE_NONE);
+
+  gtr_search_bar_set_found (dialog, found);
 }
 
 static void
