@@ -448,20 +448,8 @@ dl_activated (GSimpleAction *action,
 
   if (state == GTR_PO_STATE_MODIFIED)
     {
-      GtkWidget *dialog;
-      gint res;
-
-      dialog = gtk_message_dialog_new (GTK_WINDOW (priv->active_window),
-            GTK_DIALOG_DESTROY_WITH_PARENT,
-            GTK_MESSAGE_QUESTION,
-            GTK_BUTTONS_YES_NO,
-            _("Do you want to save the changes?"));
-      gtk_window_set_title (GTK_WINDOW (dialog), _("Warning"));
-      res = gtk_dialog_run (GTK_DIALOG (dialog));
-      gtk_widget_destroy (dialog);
-
-      if (res == GTK_RESPONSE_YES)
-        gtr_save_current_file_dialog (NULL, priv->active_window);
+      if (!gtr_want_to_save_current_dialog (priv->active_window))
+        return;
     }
 
   gtr_window_show_dlteams (priv->active_window);
@@ -657,7 +645,6 @@ gtr_application_startup (GApplication *application)
   g_set_application_name (_("Translation Editor"));
   gtk_window_set_default_icon_name (PACKAGE_APPID);
 
-
   /* Custom css */
   priv->provider = gtk_css_provider_new ();
   gtk_css_provider_load_from_resource (priv->provider, "/org/gnome/translator/styles.css");
