@@ -1,20 +1,20 @@
 /*
- * (C) 2007 Pablo Sanxiao <psanxiao@gmail.com>
- *          Ignacio Casal Quinteiro <icq@gnome.org>
- *     2008 Igalia
+ * Copyright (C) 2007  Pablo Sanxiao <psanxiao@gmail.com>
+ *                     Ignacio Casal Quinteiro <icq@gnome.org>
+ *               2008  Igalia
  *
- * gtranslator is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or   
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * gtranslator is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Pablo Sanxiao <psanxiao@gmail.com>
@@ -184,6 +184,20 @@ gtr_header_class_init (GtrHeaderClass * klass)
   object_class->dispose = gtr_header_dispose;
 }
 
+static void
+gtr_header_set_defaults (GtrHeader *header)
+{
+  g_autofree gchar* mime_version = gtr_header_get_mime_version (header);
+  g_autofree gchar* prj_id_version = gtr_header_get_prj_id_version (header);
+
+  if (!mime_version || *mime_version == '\0')
+    gtr_header_set_mime_version (header, "1.0");
+  if (!prj_id_version || *prj_id_version == '\0')
+    gtr_header_set_prj_id_version (header, "unnamed project");
+
+}
+
+
 /* Public methods */
 
 /**
@@ -206,6 +220,8 @@ gtr_header_new (po_message_iterator_t iter, po_message_t message)
   /* We have to parse the number of plurals */
   parse_nplurals (header);
 
+  gtr_header_set_defaults (header);
+
   return header;
 }
 
