@@ -32,6 +32,7 @@
 #include "gtr-po.h"
 #include "gtr-view.h"
 #include "gtr-message-table-model.h"
+#include "gtr-search-bar.h"
 
 G_BEGIN_DECLS
 /*
@@ -159,6 +160,11 @@ void gtr_tab_sort_by (GtrTab *tab, GtrMessageTableSortBy sort);
 
 void gtr_tab_find_replace (GtrTab *tab, gboolean set);
 
+void gtr_tab_show_hide_search_bar (GtrTab * tab, gboolean show);
+void gtr_tab_find_next (GtrTab * tab);
+void gtr_tab_find_prev (GtrTab * tab);
+void gtr_tab_find_set_replace (GtrTab * tab, gboolean replace);
+
 /* Semi-public methods */
 
 gchar *_gtr_tab_get_name (GtrTab * tab);
