@@ -1,22 +1,22 @@
 /*
- * (C) 2000-2007 	Fatih Demir <kabalak@kabalak.net>
- *			Ross Golder <ross@golder.org>
- *			Gediminas Paulauskas <menesis@kabalak.net>
- *			Peeter Vois <peeter@kabalak.net>
- * 			Ignacio Casal Quinteiro <nacho.resa@gmail.com>
+ * Copyright (C) 2000-2007  Fatih Demir <kabalak@kabalak.net>
+ *                          Ross Golder <ross@golder.org>
+ *                          Gediminas Paulauskas <menesis@kabalak.net>
+ *                          Peeter Vois <peeter@kabalak.net>
+ *                          Ignacio Casal Quinteiro <nacho.resa@gmail.com>
  *
- * gtranslator is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or   
- *    (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- * gtranslator is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
- *    GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
